==> nextcloud-28.0.11.tgz: nextcloud/apps/twofactor_totp/l10n/da.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du har aktiveret to-faktor godkendelse til din konto",
    "You disabled TOTP two-factor authentication for your account" : "Du har deaktiveret to-fakto godkendelse til din konto.",
    "TOTP two-factor authentication disabled by an admin" : "To-faktor-godkendelse deaktiveret af en administrator",
    "TOTP (Authenticator app)" : "TOTP (Gokendelses app)",
    "Authenticate with a TOTP app" : "Godkend med en TOTP App",
    "Two-Factor TOTP Provider" : "To-faktor TOTP-udbyder",
    "TOTP two-factor provider" : "TOTP to-faktor udbyder",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "En to-faktor-godkendelsesudbyder til TOTP (RFC 6238)",
    "Enable TOTP" : "Aktiver TOTP",
    "Could not enable TOTP" : "Kunne ikke aktivere TOTP",
    "Could not verify your key. Please try again" : "Kunne ikke bekræfte din nøgle. Prøv venligst igen",
    "Your new TOTP secret is:" : "Din nye TOTP-hemmelighed er:",
    "For quick setup, scan this QR code with your TOTP app:" : "For hurtig opsætning skal du scanne denne QR-kode med din TOTP-app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Når du har konfigureret din app, skal du indtaste en testkode nedenfor for at sikre, at alt fungerer korrekt:",
    "Authentication code" : "Autorisationskode",
    "Verify" : "Bekræft",
    "Get the authentication code from the two-factor authentication app on your device." : "Få godkendelses koden fra two-factor godkendelses app på din enhed. ",
    "Submit" : "Indsend"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/da.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Du har aktiveret to-faktor godkendelse til din konto",
    "You disabled TOTP two-factor authentication for your account" : "Du har deaktiveret to-fakto godkendelse til din konto.",
    "TOTP (Authenticator app)" : "TOTP (Gokendelses app)",
    "Authenticate with a TOTP app" : "Godkend med en TOTP App",
    "Two-Factor TOTP Provider" : "To-faktor TOTP-udbyder",
    "Enable TOTP" : "Aktiver TOTP",
    "Could not enable TOTP" : "Kunne ikke aktivere TOTP",
    "Could not verify your key. Please try again" : "Kunne ikke bekræfte din nøgle. Prøv venligst igen",
    "Your new TOTP secret is:" : "Din nye TOTP-hemmelighed er:",
    "For quick setup, scan this QR code with your TOTP app:" : "For hurtig opsætning skal du scanne denne QR-kode med din TOTP-app:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Når du har konfigureret din app, skal du indtaste en testkode nedenfor for at sikre, at alt fungerer korrekt:",
    "Authentication code" : "Autorisationskode",
    "Verify" : "Bekræft",
    "Get the authentication code from the two-factor authentication app on your device." : "Få godkendelses koden fra two-factor godkendelses app på din enhed. ",
    "Submit" : "Indsend",
    "TOTP two-factor authentication disabled by an admin" : "To-faktor-godkendelse deaktiveret af en administrator",
    "TOTP two-factor provider" : "TOTP to-faktor udbyder",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "En to-faktor-godkendelsesudbyder til TOTP (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
